Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrClosed = stderr.New("channel has closed, do not recevie value anymore.")
ErrClosed returned if Append called after Close()
Functions ¶
This section is empty.
Types ¶
type Channel ¶
type Channel interface {
// Close will block until all data in channel consumed completely
Close()
// T return channel's typeof
T() string
// Append value into channel, the value must be format of typeof defined in NewChannel
Append(value interface{}) error
}
Channel a graceful-close channel
Click to show internal directories.
Click to hide internal directories.